# RentcastPropertyRecords200ResponseInnerTaxAssessments2022


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**year** | **float** |  | [optional] [default to ]
**value** | **float** |  | [optional] [default to ]
**land** | **float** |  | [optional] [default to ]
**improvements** | **float** |  | [optional] [default to ]

## Example

```python
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2022 import RentcastPropertyRecords200ResponseInnerTaxAssessments2022

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastPropertyRecords200ResponseInnerTaxAssessments2022 from a JSON string
rentcast_property_records200_response_inner_tax_assessments2022_instance = RentcastPropertyRecords200ResponseInnerTaxAssessments2022.from_json(json)
# print the JSON string representation of the object
print(RentcastPropertyRecords200ResponseInnerTaxAssessments2022.to_json())

# convert the object into a dict
rentcast_property_records200_response_inner_tax_assessments2022_dict = rentcast_property_records200_response_inner_tax_assessments2022_instance.to_dict()
# create an instance of RentcastPropertyRecords200ResponseInnerTaxAssessments2022 from a dict
rentcast_property_records200_response_inner_tax_assessments2022_from_dict = RentcastPropertyRecords200ResponseInnerTaxAssessments2022.from_dict(rentcast_property_records200_response_inner_tax_assessments2022_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


